/* AccessibleExtendedTable.java -- aids in extended table access
   Copyright (C) 2002 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package javax.accessibility;

/**
 * Objects which present 2-D tables with the extension of a flat address
 * space should implement this interface.  Accessibility software can use the
 * implementations of this interface to better manipulate the table.
 *
 * <p>The <code>AccessibleContext.getAccessibleTable()</code> method
 * should return an instance of this interface only when it is supported.
 *
 * @author Eric Blake <ebb9@email.byu.edu>
 * @see Accessible
 * @see AccessibleContext
 * @see AccessibleContext#getAccessibleTable()
 * @since 1.2
 * @status updated to 1.4
 */
public interface AccessibleExtendedTable extends AccessibleTable
{
  /**
   * Returns the row number of an index in the table.
   *
   * @param index the cell index, in row-major form from (0,0)
   * @return the row number, or -1 if out of bounds
   */
  int getAccessibleRow(int index);

  /**
   * Returns the column number of an index in the table.
   *
   * @param index the cell index, in row-major form from (0,0)
   * @return the column number, or -1 if out of bounds
   */
  int getAccessibleColumn(int index);

  /**
   * Returns the cell number for a row-major address from (0,0).
   *
   * @param r the row
   * @param c the column
   * @return the cell index
   */
   int getAccessibleIndex(int r, int c);
} // interface AccessibleExtendedTable
